"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fecha = require("fecha");
class DefaultWriter {
    log(msg) {
        console.log(msg);
    }
    error(msg) {
        console.log(msg);
    }
    get link() {
        return this._other;
    }
    set link(other) {
        this._other = other;
    }
}
fecha.masks.myMask = 'YYYY-MM-DD HH:mm:ss.SSS';
let _writer = new DefaultWriter();
let _format = ':time: > :name: - :msg:';
class Logger {
    constructor(name = '') {
        this.name = name;
    }
    static get writer() {
        return _writer;
    }
    static set writer(writer) {
        _writer = writer;
    }
    static get format() {
        return _format;
    }
    static set format(format) {
        _format = format;
    }
    _makeMsg(msgs) {
        const time = fecha.format(new Date(), 'myMask');
        return _format.replace(':time:', time)
            .replace(':name:', this.name).replace(':msg:', msgs.join(' '));
    }
    log(...msgs) {
        const msg = this._makeMsg(msgs);
        let writer = Logger.writer;
        while (writer) {
            writer.log(msg);
            writer = writer.link;
        }
    }
    error(...msgs) {
        const msg = this._makeMsg(msgs);
        let writer = Logger.writer;
        while (writer) {
            writer.error(msg);
            writer = writer.link;
        }
    }
}
exports.Logger = Logger;
exports.default = Logger;
